/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2010 Martin Rexa
 */

package cz.xelfi.quoridor.statistics.resources;

import com.sun.jersey.api.client.Client;
import com.sun.jersey.api.client.WebResource;
import com.sun.jersey.core.header.MediaTypes;
import com.sun.net.httpserver.HttpServer;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.net.URI;
import java.util.Locale;
import javax.ws.rs.core.MediaType;
import org.junit.AfterClass;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;
import static org.junit.Assert.*;
import cz.xelfi.quoridor.statistics.EloList;
/**
 *
 * @author Martin Rexa
 */
public class StatisticsTest {
    private static File dir;
    private static File fGames;
    private static HttpServer stopAPI;
    private WebResource apiResource;

    public StatisticsTest() throws Exception {
    }

    @BeforeClass
    public static void localeEnglish() throws Exception {
        Locale.setDefault(Locale.ENGLISH);
        dir = File.createTempFile("quoridor", ".dir");
        dir.delete();
        dir.mkdirs();
        fGames = new File(dir, "games");
        fGames.mkdirs();

        System.setProperty("quoridor.dir", dir.getPath());
        stopAPI = Statistics.start(9990);

        File passwd = new File(dir, "passwd");
        FileOutputStream os = new FileOutputStream(passwd);
        os.write("test=pes\nJarda=darda\n".getBytes("UTF-8"));
        os.close();
    }

    @Before
    public void setUp() throws Exception {
        Client client = new Client();
        apiResource = client.resource(new URI("http://localhost:9990/"));
    }

    @AfterClass
    public static void cleanUpAll() throws Exception {
        deleteRec(dir);
        if (stopAPI != null) {
            stopAPI.stop(0);
        }
    }

    static void deleteRec(File dir) throws IOException {
        if (dir == null) {
            return;
        }
        File[] arr = dir.listFiles();
        if (arr != null) {
            for (File f : arr) {
                deleteRec(f);
            }
        }
        dir.delete();
    }

    @Test public void testApplicationWadl() {
        String serviceWadl = apiResource.path("application.wadl").
                accept(MediaTypes.WADL).get(String.class);
        assertTrue(serviceWadl.length() > 0);
    }

    @Test public void testEloList() throws Exception {
        createFile(fGames, "g1", "# white: W\n# black: B\n# status: IN_PROGRESS\nN S\n\n");
        createFile(fGames, "g2", "# white: W\n# black: B\n# status: blackWon\nRESIGN\n\n");
        createFile(fGames, "g3", "# white: W\n# black: B\n# status: blackWon\nRESIGN\n\n");
        createFile(fGames, "g4", "# white: W\n# black: B\n# status: blackWon\nRESIGN\n\n");
        Statistics.processGames();

        EloList eloList = apiResource.path("elo").path("list").accept(MediaType.TEXT_XML).get(EloList.class);
//        assertFalse(eloList.getFinalList().isEmpty());
//        System.out.println("ELO LIST");
//        for (EloEntry entry : eloList.getFinalList()){
//            System.out.println(entry);
//        }
    }

    private void createFile(File dir, String filename, String content) throws Exception{
        File f = new File(dir, filename);
        FileOutputStream os = new FileOutputStream(f);
        os.write(content.getBytes("UTF-8"));
        os.close();
    }

}
